<template>
  <div :class="{'has-logo':showLogo}">

    <logo v-if="showLogo" :collapse="isCollapse" />

    <div
      v-if="$store.state.app.sidebar.opened&&!$store.state.settings.menuIsHorizontal"
      :class="{'leftBackgroundColorValue':!$store.state.settings.leftBackgroundColorValue,
               'leftBackgroundLogo':!$store.state.settings.leftBackgroundColorValue}"
      class="layoutLogo"
    />

    <el-scrollbar wrap-class="scrollbar-wrapper" class="scrollbarWrapperClass">
      <el-menu
        v-if="!$store.state.settings.menuIsHorizontal"
        :default-active="activeMenu"
        :collapse="isCollapse"
        :background-color="!$store.state.settings.leftBackgroundColorValue?'#f8f8fa':variables.menuBg"
        :text-color="!$store.state.settings.leftBackgroundColorValue?`rgb(48, 65, 86,0.8)`:variables.menuText"
        :active-text-color="variables.menuActiveText"
        :collapse-transition="false"
        :unique-opened="false"
        mode="vertical"
      >
        <!--        <sidebar-item-->
        <!--          v-for="route in routes"-->
        <!--          :key="route.path"-->
        <!--          class="el-scrollbar-menu"-->
        <!--          :item="route"-->
        <!--          :base-path="route.path"-->
        <!--        />-->

        <sidebar-item
          v-for="route in permission_routes"
          :key="route.path"
          :item="route"
          :base-path="route.path"
        />

      </el-menu>
    </el-scrollbar>
    <div v-if="!$store.state.settings.menuIsHorizontal" style="position: absolute;bottom: 20px;left: 30px;">
      <div>
        <el-button v-if="$store.state.app.sidebar.opened" type="text" style="font-size: 14px;cursor: pointer">
          新凯迪制造V2.0.0
        </el-button>
        <!--        <el-button type="text"><a href="http://www.ykxkd.com/" target="_blank">新凯迪制造V1.0.01</a></el-button>-->
      </div>
    </div>

  </div>
</template>

<script>
import { mapGetters } from 'vuex'
import Logo from './Logo'
import SidebarItem from './SidebarItem'
import variables from '@/styles/variables.scss'
import { removeCookie, setCookie } from '@/utils/auth'
import Vue from 'vue'

export default {
  components: { SidebarItem, Logo },
  data() {
    return {
      routers: []
    }
  },
  computed: {
    ...mapGetters([
      'permission_routes',
      'sidebar'
    ]),
    routes() {
      return this.$router.options.routes
    },
    activeMenu() {
      const route = this.$route
      const { meta, path } = route
      // console.log(meta, path, 7)
      // if set path, the sidebar will highlight the path you set
      removeCookie('ruleCode')
      setCookie('ruleCode', meta.code) // 将编码规则code存到cookie里面

      removeCookie('datacode')
      setCookie('datacode', meta.datacode) // 数据权限

      Vue.prototype.$buttoncode = meta.buttoncode // 按钮权限

      if (meta.activeMenu) {
        return meta.activeMenu
      }

      if (path.indexOf('kanbanManager') !== -1) { // 当点击智慧看板的时候
        const url = this.$router.resolve({
          path
          // query: { id: 123 }
        })

        const t = url.href.split('/')
        // console.log(t, 't')
        window.open('#/' + t[2], '_blank')
      }

      return path
    },
    showLogo() {
      return this.$store.state.settings.sidebarLogo
    },
    variables() {
      // console.log(variables, 2333)
      // 先输出这个variables值  然后修改其属性值
      variables.menuActiveText = this.$store.state.settings.theme
      // console.log(!this.$store.state.settings.menuIsHorizontal && !this.$store.state.settings.leftBackgroundColorValue, 1)
      if ((!this.$store.state.settings.menuIsHorizontal && !this.$store.state.settings.leftBackgroundColorValue)) {
        variables.menuHover = '#eee'
      }

      return variables
    },
    isCollapse() {
      return !this.sidebar.opened
    }
  }
}
</script>
<style lang="scss">
//$main_color: #42b983;

.layoutLogo {
  position: absolute;
  top: 5px;
  z-index: 10;
  left: 5px;
  width: 200px;
  height: 90px;
  background: url("../../../assets/images/layout_3.png") no-repeat;
}

.leftBackgroundLogo {
  background: url("../../../assets/images/layout_2.png") no-repeat;
}

.leftBackgroundColorValue {
  background-color: #f8f8fa;
}

.scrollbarWrapperClass {
  margin-top: 90px;
  height: calc(85% - 45px) !important;
}

.el-button--text, .el-button--text.is-disabled, .el-button--text.is-disabled:focus, .el-button--text.is-disabled:hover, .el-button--text:active {
  color: white;
  font-size: 18px;
}

.el-button--text:focus {
  color: white;
}

//#app .sidebar-container .el-submenu .el-menu-item {
//  background-color: transparent !important;
//}

//#app .sidebar-container .el-submenu .el-menu-item.is-active {
//background: $main_color !important;
//color: #fff !important;
//font-weight: bolder !important;
//}
//
//#app .sidebar-container .el-submenu .el-menu-item:hover {
//  background: $main_color !important;
//  //color: #fff !important;
//}

.el-submenu__title {
  font-weight: bolder;
}

//.sub-el-icon::before {
//  color: $main_color;
//}
//
//.svg-icon {
//  color: $main_color;
//}

.submenu-title-noDropdown {
  font-weight: bolder;
}

//.router-link-exact-active > .submenu-title-noDropdown {
//  color: $main_color !important;
//}
//
//.el-menu-item.is-active {
//  color: $main_color !important;
//}

.el-button--text:hover {
  color: #ffffff;
  cursor: default;
}

//.el-menu {
//  background-color: #213145 !important;
//}
</style>
